@@ -126,13 +126,10 @@ def run_tesseract(input_file, output_file, language="deu"):
 
     with io.BytesIO() as transfer:
         with WandImage(filename=input_file) as img:
-            img.auto_level()
-            img.sharpen(radius=0, sigma=4.0)
-            img.contrast()
             img.save(transfer)
 
         with Image.open(transfer) as img:
-            image_data = pytesseract.image_to_string(img, lang=language, timeout=60)
+            image_data = pytesseract.image_to_string(img, lang=language, timeout=60, config="--psm 6")
 
             out = open(output_file, "w")
             out.write(image_data)
